summaryrefslogtreecommitdiffstats
path: root/src/profileengine/lib/profileengine.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/profileengine/lib/profileengine.h')
-rw-r--r--src/profileengine/lib/profileengine.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/profileengine/lib/profileengine.h b/src/profileengine/lib/profileengine.h
index d630f576..36d85697 100644
--- a/src/profileengine/lib/profileengine.h
+++ b/src/profileengine/lib/profileengine.h
@@ -61,27 +61,27 @@ public:
/**
Profile engine.
-- Uses TDevelop profiles to form lists of plugin offers;
+- Uses KDevelop profiles to form lists of plugin offers;
- Provides means of managing profiles;
- Provides means to access the resources provided by a profile.
-TDevelop profiles form a tree with a root profile named "TDevelop".
+KDevelop profiles form a tree with a root profile named "KDevelop".
For example, such profiles tree can look as:
@code
-TDevelop
+KDevelop
- IDE
- CompiledLanguageIDE
- AdaIDE
- CandCppIDE
- CIDE
- CppIDE
- - TDECppIDE
+ - KDECppIDE
- FortranIDE
...
- DatabaseIDE
- ScriptingLanguageIDE
..
-- TDevAssistant
+- KDevAssistant
@endcode
To manage a tree of profiles, use @ref ProfileEngine::walkProfiles methods.
*/
@@ -92,7 +92,7 @@ public:
/**Type of the plugin offer. Engine will usually find profiles and return offers
of selected type.
- @sa TDevPlugin class documentation for more information of plugin types.*/
+ @sa KDevPlugin class documentation for more information of plugin types.*/
enum OfferType {
Global /**<Global plugins.*/,
Project /**<Project plugins.*/,
@@ -137,8 +137,8 @@ public:
void diffProfiles(OfferType offerType, const TQString &profile1, const TQString &profile2,
TQStringList &unload, TDETrader::OfferList &load);
- /**@return The root profile. Root profile is always named "TDevelop" and it
- defines an empty list of plugins. Applications built on TDevelop platform
+ /**@return The root profile. Root profile is always named "KDevelop" and it
+ defines an empty list of plugins. Applications built on KDevelop platform
will define nested profiles.*/
Profile *rootProfile() const { return m_rootProfile; }
/**Finds a profile with given name.